smartcard.Observer

# ``smartcard`.`Observer``

module documentation

from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html

(c) Copyright 2008, Creative Commons Attribution-Share Alike 3.0.

Class support for "observer" pattern.

The observer class is the base class for all smartcard package observers.

Class | `Observable` | No class docstring; 0/2 instance variable, 1/9 method documented
Class | `Observer` | No class docstring; 1/1 method documented